<?php

namespace TDevAgency\FilesManager\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;
use TDevAgency\FilesManager\ResourceModels\TdfmFile;

class SymlinksCommand extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'fm:symlinks {--id=}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command description';


    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {

        if ($this->hasOption('id') && $this->option('id') !== null) {

            $files = TdfmFile::where('id', $this->option('id'))->get();
        } else {
            $files = TdfmFile::get();

            if (file_exists(public_path('media'))) {
                File::deleteDirectory(public_path('media'), true);
            }
        }

        if ($files->isEmpty()) {
            return;
        }

        $sizes = array_keys(Config::get('tdfm.sizes'));

        if (!file_exists(public_path('media'))) {
            File::makeDirectory(public_path('media'));
        }

        /** @var TdfmFile $file */
        foreach ($files as $file) {
            if ($file->original_name === $file->name) {
                continue;
            }

//            continue if file physically doesn't exists on the server
            if (!Storage::disk('tdfm_original')->exists($file->name)) {
                continue;
            }


            if (!file_exists(public_path('media/' . $file->id))) {
                File::makeDirectory(public_path('media/' . $file->id));
            }

            $pathInfo = pathinfo($file->original_name);
            $pathInfoCached = pathinfo($file->name);
            File::link(Storage::disk('tdfm_original')->path($file->name), public_path('media/' . $file->id . '/' . $file->original_name));
            if (Storage::disk('tdfm_generated')->exists($file->id)) {


                $webpName = $pathInfoCached['filename'] . '.webp';
                $newWebpName = $pathInfo['filename'] . '.webp';

                // TODO SVG
                foreach ($sizes as $size) {
                    if (!Storage::disk('tdfm_generated')->exists($file->id . '/' . $size)) {

                    } else {

                        if (!file_exists(public_path('media/' . $file->id . '/' . $size))) {
                            File::makeDirectory(public_path('media/' . $file->id . '/' . $size));
                        }
                        File::link(Storage::disk('tdfm_generated')->path($file->id . '/' . $size . '/' . $file->name), public_path('media/' . $file->id . '/' . $size . '/' . $file->original_name));
                        if (Storage::disk('tdfm_generated')->exists($file->id . '/' . $size . '/' . $webpName)) {
                            File::link(Storage::disk('tdfm_generated')->path($file->id . '/' . $size . '/' . $webpName), public_path('media/' . $file->id . '/' . $size . '/' . $newWebpName));
                        }
                    }
                }
            }
        }
    }
}
