<?php


namespace TDevAgency\FilesManager;


use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\View;
use TDevAgency\FilesManager\ResourceModels\TdfmFile;

trait MediaHelper
{
    public function getImage($id, $size = null, $webp = false)
    {
        /** @var TdfmFile $filesManager */
        $filesManager = Cache::rememberForever('tdfm_file_by_id_' . $id, function () use ($id) {
            return TdfmFile::find($id);
        });
        if ($filesManager === null) {
            return null;
        }

        $isSvg = strpos($filesManager->name, '.svg') !== false;

        if (strpos(request()->headers->get('accept'), 'image/webp') !== false && !$isSvg) {
            $webp = true;
            if ($size === null) {
                $size = 'xl';
            }
        }

        if ($webp) {
            $filesManager->original_name = str_replace(['jpg', 'jpeg', 'png', 'gif'], ['webp', 'webp', 'webp', 'webp'], $filesManager->name);
        }

        if ($size === null) {
            return asset('media/' . $id . '/' . $filesManager->original_name);
        }

        return asset('media/' . $id . '/' . $size . '/' . $filesManager->original_name);
    }


    public function getPictureTag($id, $size = null)
    {

        if ($id === null) {
            return null;
        }
        $size = $size === null ? 'xl' : $size;


        $filesManager = Cache::rememberForever('tdfm_file_by_id_' . $id, function () use ($id) {
            return TdfmFile::findOrFail($id);
        });

        $filesManager->webpName = str_replace(['jpg', 'jpeg', 'png', 'gif'], ['webp', 'webp', 'webp', 'webp'], $filesManager->name);
        $tag = [
            'sources' => [],
            'src' => preg_match('/^(\w+)(\.)(svg)+$/', $filesManager->name) ? asset('media/original/' . $filesManager->name) :
                asset('media/' . $id . '/' . $size . '/' . $filesManager->name)
        ];
        if (preg_match('/^image\/(jpe?g|gif|png)+$/', $filesManager->file_mime)) {
            $tag['sources'][] = [
                'src' => asset('media/' . $id . '/' . $size . '/' . $filesManager->webpName),
                'mime' => 'image/webp',
            ];
            $tag['sources'][] = [
                'src' => asset('media/' . $id . '/' . $size . '/' . $filesManager->name),
                'mime' => $filesManager->file_mime,
            ];
        }

        return View::make('files-manager::picture')->with('picture', $tag)->render();
    }

}
